@@ -1,6 +1,6 @@
 /* Lisp eval
    Copyright (c) 2001 Scott "Jerry" Lawrence.
-   Copyright (c) 2005 Reuben Thomas.
+   Copyright (c) 2005-2006 Reuben Thomas.
    All rights reserved.
 
    This file is part of Zile.
@@ -20,7 +20,7 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: eval.c,v 1.24 2005/07/11 06:10:25 rrt Exp $	*/
+/*	$Id: eval.c,v 1.28 2006/11/30 14:58:31 rrt Exp $	*/
 
 #include <assert.h>
 #include <stdio.h>
@@ -33,10 +33,46 @@
 #include "vars.h"
 
 
+static le *eval_cb_command_helper(Function f, int argc, le *branch)
+{
+  int ret = f(argc, branch);
+  return ret ? leT : leNIL;
+}
+
+#define X(zile_name, c_name) \
+  static le *eval_cb_ ## c_name(int argc, le *branch) \
+  { \
+    return eval_cb_command_helper(F_ ## c_name, argc, branch); \
+  }
+#define X0(zile_name, c_name)                    X(zile_name, c_name)
+#define X1(zile_name, c_name, key1)              X(zile_name, c_name)
+#define X2(zile_name, c_name, key1, key2)        X(zile_name, c_name)
+#define X3(zile_name, c_name, key1, key2, key3)  X(zile_name, c_name)
+#include "tbl_funcs.h"
+#undef X
+#undef X0
+#undef X1
+#undef X2
+#undef X3
+
+
 static evalLookupNode evalTable[] = {
   { "set"	, eval_cb_set		},
   { "setq"	, eval_cb_setq		},
-  { NULL	, NULL			}
+#define X0(zile_name, c_name) \
+  { zile_name   , eval_cb_ ## c_name },
+#define X1(zile_name, c_name, key1) \
+  { zile_name   , eval_cb_ ## c_name },
+#define X2(zile_name, c_name, key1, key2) \
+  { zile_name   , eval_cb_ ## c_name },
+#define X3(zile_name, c_name, key1, key2, key3) \
+  { zile_name   , eval_cb_ ## c_name },
+#include "tbl_funcs.h"
+#undef X0
+#undef X1
+#undef X2
+#undef X3
+  { NULL	, NULL			},
 };
 
 
@@ -72,11 +108,12 @@ le *evaluateBranch(le *trybranch)
   prim = lookupFunction(keyword->data);
   leWipe(keyword);
   if (prim)
-    return prim(countNodes(trybranch), trybranch);
+    return prim(0, trybranch);
 
   return NULL;
 }
 
+
 le *evaluateNode(le *node)
 {
   le *value;
@@ -91,10 +128,10 @@ le *evaluateNode(le *node)
       value = evaluateBranch(node->branch);
 
   } else {
-    le *temp = variableGet(mainVarList, node->data);
+    value = variableGet(mainVarList, node->data);
 
-    if (temp != NULL)
-      value = leDup(temp);
+    if (value != NULL)
+      value = leDup(value);
     else
       value = leNew(node->data);
   }
@@ -112,8 +149,9 @@ int countNodes(le *branch)
 }
 
 
-le *eval_cb_set_helper(enum setfcn function, int argc, le *branch)
+static le *eval_cb_set_helper(enum setfcn function, le *branch)
 {
+  int argc = countNodes(branch);
   le *newkey = NULL /* XXX unnecessary */, *newvalue = leNIL, *current;
 
   if (branch != NULL && argc >= 3) {
@@ -138,12 +176,12 @@ le *eval_cb_set_helper(enum setfcn function, int argc, le *branch)
   return newvalue;
 }
 
-le* eval_cb_set(int argc, le *branch)
+le *eval_cb_set(int argc GCC_UNUSED, le *branch)
 {
-  return eval_cb_set_helper(S_SET, argc, branch);
+  return eval_cb_set_helper(S_SET, branch);
 }
 
-le *eval_cb_setq(int argc, le *branch)
+le *eval_cb_setq(int argc GCC_UNUSED, le *branch)
 {
-  return eval_cb_set_helper(S_SETQ, argc, branch);
+  return eval_cb_set_helper(S_SETQ, branch);
 }
