@@ -1,3 +1,5 @@
+#include "eval.h"
+
 /* basic.c ---------------------------------------------------------------- */
 size_t get_goalc_bp(Buffer *bp, Point pt);
 size_t get_goalc_wp(Window *wp);
@@ -29,6 +31,7 @@ char *get_function_name(Function p);
 /* buffer.c --------------------------------------------------------------- */
 void calculate_region(Region *rp, Point from, Point to);
 int calculate_the_region(Region *rp);
+void init_buffer(Buffer *bp);
 Buffer *create_buffer(const char *name);
 void free_buffer(Buffer *bp);
 void free_buffers(void);
@@ -272,7 +275,7 @@ int zasprintf(char **ptr, const char *fmt, ...);
  * Declare external Zile functions.
  */
 #define X0(zile_name, c_name)			\
-	extern int F_ ## c_name(int uniarg);
+	extern int F_ ## c_name(int uniarg, le *l);
 #define X1(zile_name, c_name, k1)		\
 	X0(zile_name, c_name)
 #define X2(zile_name, c_name, k1, k2)		\
