@@ -20,7 +20,7 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: macro.c,v 1.19 2005/09/15 21:47:13 rrt Exp $	*/
+/*	$Id: macro.c,v 1.20 2006/11/29 20:57:02 rrt Exp $	*/
 
 #include "config.h"
 
@@ -76,7 +76,7 @@ void cancel_kbd_macro(void)
   thisflag &= ~FLAG_DEFINING_MACRO;
 }
 
-DEFUN_INT("start-kbd-macro", start_kbd_macro)
+DEFUN("start-kbd-macro", start_kbd_macro)
 /*+
 Record subsequent keyboard input, defining a keyboard macro.
 The commands are recorded even as they are executed.
@@ -100,7 +100,7 @@ Use M-x name-last-kbd-macro to give it a permanent name.
 }
 END_DEFUN
 
-DEFUN_INT("end-kbd-macro", end_kbd_macro)
+DEFUN("end-kbd-macro", end_kbd_macro)
 /*+
 Finish defining a keyboard macro.
 The definition was started by C-x (.
@@ -117,7 +117,7 @@ The macro is now available for use via C-x e.
 }
 END_DEFUN
 
-DEFUN_INT("name-last-kbd-macro", name_last_kbd_macro)
+DEFUN("name-last-kbd-macro", name_last_kbd_macro)
 /*+
 Assign a name to the last keyboard macro defined.
 Argument SYMBOL is the name to define.
@@ -170,7 +170,7 @@ void call_macro(Macro *mp)
     ungetkey(mp->keys[i]);
 }
 
-DEFUN_INT("call-last-kbd-macro", call_last_kbd_macro)
+DEFUN("call-last-kbd-macro", call_last_kbd_macro)
 /*+
 Call the last keyboard macro that you defined with C-x (.
 A prefix argument serves as a repeat count.
