@@ -1,6 +1,6 @@
 /* Program invocation, startup and shutdown
    Copyright (c) 1997-2004 Sandro Sigala.
-   Copyright (c) 2004-2005 Reuben Thomas.
+   Copyright (c) 2004-2006 Reuben Thomas.
    All rights reserved.
 
    This file is part of Zile.
@@ -20,7 +20,7 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: main.c,v 1.102 2006/07/20 19:58:15 rrt Exp $	*/
+/*	$Id: main.c,v 1.104 2006/11/30 14:58:31 rrt Exp $	*/
 
 #include "config.h"
 
@@ -285,6 +285,14 @@ int main(int argc, char **argv)
   if (bflag)
     printf(astr_cstr(as));
   else {
+    term_init();
+
+    /* Create the `*scratch*' buffer. */
+    create_first_window();
+    term_redisplay();
+
+    /* Read settings after creating *scratch* buffer so that any
+       buffer commands won't cause a crash. */
     if (!qflag) {
       le *list;
 
@@ -296,11 +304,8 @@ int main(int argc, char **argv)
       leWipe(list);
     }
 
-    term_init();
-
-    /* Create the `*scratch*' buffer and initialize key bindings. */
-    create_first_window();
-    term_redisplay();
+    /* Reinitialise the *scratch* buffer to catch settings */
+    init_buffer(cur_bp);
 
     if (argc >= 1)
       while (*argv) {
