@@ -17,10 +17,10 @@
 
    You should have received a copy of the GNU General Public License
    along with Zile; see the file COPYING.  If not, write to the Free
-   Software Foundation, 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.  */
+   Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
+   02111-1301, USA.  */
 
-/*	$Id: strrstr.c,v 1.2 2004/12/20 18:23:22 rrt Exp $	*/
+/*	$Id: strrstr.c,v 1.5 2005/07/11 06:10:26 rrt Exp $	*/
 
 #include "config.h"
 
@@ -31,17 +31,18 @@
 char *strrstr(const char *s, const char *t);
 
 char *strrstr(const char *s, const char *t) {
-        int i, j, slen = strlen(s), tlen = strlen(t);
+  int i, j, slen = strlen(s), tlen = strlen(t);
 
-        if (slen < tlen)
-                return NULL;
+  if (slen < tlen)
+    return NULL;
 
-	for (i = slen - tlen; i > 0; i--) {
-		for (j = 0; j < tlen && s[i + j] == t[j]; j++);
-                if (j == tlen)
-                        return (char *)(s + i);
-        }
-	return NULL;
+  for (i = slen - tlen; i > 0; i--) {
+    for (j = 0; j < tlen && s[i + j] == t[j]; j++)
+      ;
+    if (j == tlen)
+      return (char *)(s + i);
+  }
+  return NULL;
 }
 
 #endif
