@@ -1,28 +1,26 @@
 /* Exported terminal
    Copyright (c) 1997-2004 Sandro Sigala.
-   Copyright (c) 2003-2004 Reuben Thomas.
+   Copyright (c) 2003-2005 Reuben Thomas.
    Copyright (c) 2004 David A. Capello.
    All rights reserved.
 
-   This file is part of Zile.
+   This file is part of Zee.
 
-   Zile is free software; you can redistribute it and/or modify it under
+   Zee is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License as published by the Free
    Software Foundation; either version 2, or (at your option) any later
    version.
 
-   Zile is distributed in the hope that it will be useful, but WITHOUT ANY
+   Zee is distributed in the hope that it will be useful, but WITHOUT ANY
    WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.
 
    You should have received a copy of the GNU General Public License
-   along with Zile; see the file COPYING.  If not, write to the Free
+   along with Zee; see the file COPYING.  If not, write to the Free
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: term_allegro.c,v 1.28 2005/07/11 06:10:26 rrt Exp $	*/
-
 #include "config.h"
 
 #include <stdio.h>
@@ -39,21 +37,6 @@
 #define FW		(8)	/* font_length (font, ...) */
 #define FH		(8)	/* font_height (font) */
 
-static Terminal thisterm = {
-  /* Unitialised screen pointer */
-  NULL,
-
-  /* Uninitialized width and height. */
-  0, 0,
-
-  /* Uninitialised. */
-  FALSE,
-};
-
-Terminal *termp = &thisterm;
-
-size_t ZILE_LINES, ZILE_COLS;
-
 /* current position and color */
 static size_t cur_x = 0;
 static size_t cur_y = 0;
@@ -69,7 +52,7 @@ static void _get_color(int c, int *_fg, int *_bg)
   fg = makecol(170, 170, 170);
   bg = makecol(0, 0, 0);
 
-  if (c & ZILE_REVERSE) {
+  if (c & FONT_REVERSE) {
     int aux = fg;
     fg = bg;
     bg = aux;
@@ -88,25 +71,23 @@ static void control_blink_state(void)
 {
   blink_state ^= 1;
 }
-
 END_OF_STATIC_FUNCTION(control_blink_state)
 
 static void inc_cur_time(void)
 {
   cur_time++;
 }
-
 END_OF_STATIC_FUNCTION(inc_cur_time)
 
 static void draw_cursor(int state)
 {
-  if (cursor_state && cur_x < ZILE_COLS && cur_y < ZILE_LINES) {
+  if (cursor_state && cur_x < term_width() && cur_y < term_height()) {
     if (state)
       rectfill(screen, (int)(cur_x * FW), (int)(cur_y * FH),
                (int)(cur_x * FW + FW - 1), (int)(cur_y * FH + FH - 1),
                makecol(170, 170, 170));
     else {
-      int fg, bg, c = new_scr[cur_y*ZILE_COLS+cur_x];
+      int fg, bg, c = new_scr[cur_y*term_width()+cur_x];
       _get_color(c, &fg, &bg);
       text_mode(bg);
       font->vtable->render_char
@@ -125,10 +106,10 @@ void term_move(size_t y, size_t x)
 
 void term_clrtoeol(void)
 {
-  if (cur_x < ZILE_COLS && cur_y < ZILE_LINES) {
+  if (cur_x < term_width() && cur_y < term_height()) {
     size_t x;
-    for (x = cur_x; x < ZILE_COLS; x++)
-      new_scr[cur_y * ZILE_COLS + x] = 0;
+    for (x = cur_x; x < term_width(); x++)
+      new_scr[cur_y * term_width() + x] = 0;
   }
 }
 
@@ -137,8 +118,8 @@ void term_refresh(void)
   int c, i, bg, fg;
   size_t x, y;
   i = 0;
-  for (y = 0; y<ZILE_LINES; y++)
-    for (x = 0; x < ZILE_COLS; x++) {
+  for (y = 0; y < term_height(); y++)
+    for (x = 0; x < term_width(); x++) {
       if (new_scr[i] != cur_scr[i]) {
         c = cur_scr[i] = new_scr[i];
         _get_color(c, &fg, &bg);
@@ -154,12 +135,12 @@ void term_refresh(void)
 
 void term_clear(void)
 {
-  memset(new_scr, 0, sizeof(short) * ZILE_COLS * ZILE_LINES);
+  memset(new_scr, 0, sizeof(short) * term_width() * term_height());
 }
 
 void term_addch(int c)
 {
-  if (cur_x < ZILE_COLS && cur_y < ZILE_LINES) {
+  if (cur_x < term_width() && cur_y < term_height()) {
     int color = 0;
 
     if (c & 0x0f00)
@@ -167,14 +148,14 @@ void term_addch(int c)
     else if (cur_color & 0x0f00)
       color |= cur_color & 0x0f00;
     else
-      color |= ZILE_NORMAL;
+      color |= FONT_NORMAL;
 
     if (c & 0xf000)
       color |= c & 0xf000;
     else
       color |= cur_color & 0xf000;
 
-    new_scr[cur_y*ZILE_COLS+cur_x] = (c & 0x00ff) | color;
+    new_scr[cur_y*term_width()+cur_x] = (c & 0x00ff) | color;
   }
   cur_x++;
 }
@@ -203,7 +184,7 @@ void term_init(void)
   set_color_depth(8);
   if (set_gfx_mode(GFX_SAFE, 640, 480, 0, 0) < 0) {
     fprintf(stderr, "Could not set VGA screen mode.");
-    zile_exit(1);
+    exit(1);
   }
 
   LOCK_VARIABLE(blink_state);
@@ -214,36 +195,20 @@ void term_init(void)
   LOCK_FUNCTION(inc_cur_time);
   install_int_ex(inc_cur_time, BPS_TO_TIMER(1000));
 
-  ZILE_COLS = SCREEN_W/FW;
-  ZILE_LINES = SCREEN_H/FH;
+  term_set_size((size_t)(SCREEN_W / FW), (size_t)(SCREEN_H / FH));
 
-  termp->screen = screen;
-  termp->width = ZILE_COLS;
-  termp->height = ZILE_LINES;
-
-  cur_scr = zmalloc(sizeof(short) * ZILE_COLS * ZILE_LINES);
-  new_scr = zmalloc(sizeof(short) * ZILE_COLS * ZILE_LINES);
+  cur_scr = zmalloc(sizeof(short) * term_width() * term_height());
+  new_scr = zmalloc(sizeof(short) * term_width() * term_height());
 }
 
 void term_close(void)
 {
   /* Free memory and finish with allegro. */
-  termp->screen = NULL;
   free(cur_scr);
   free(new_scr);
 
-  set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
-  allegro_exit ();
-}
-
-/* Suspend the term ready to go back to the shell */
-void term_suspend(void)
-{
-}
-
-/* Set up the term again */
-void term_resume(void)
-{
+  set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
+  allegro_exit();
 }
 
 static int translate_key(int c)
@@ -255,7 +220,7 @@ static int translate_key(int c)
     ascii = scancode_to_ascii(scancode);
     if (ascii)
       return KBD_META | ascii |
-        ((key_shifts & KB_CTRL_FLAG) ? KBD_CTL : 0);
+        ((key_shifts & KB_CTRL_FLAG) ? KBD_CTRL : 0);
     else
       return KBD_NOKEY;
   }
@@ -290,19 +255,19 @@ static int translate_key(int c)
   case KEY_DOWN: return KBD_DOWN;
   case KEY_SPACE:
     if (key_shifts & KB_CTRL_FLAG)
-      return '@' | KBD_CTL;
+      return '@' | KBD_CTRL;
     else
       return ' ';
   default:
     if ((scancode >= KEY_0 && scancode <= KEY_9) &&
         (ascii < 32 || ascii == 127)) {
-      return ('0'+scancode-KEY_0) | KBD_CTL;
+      return ('0'+scancode-KEY_0) | KBD_CTRL;
     }
-    else if (ascii >= 1 && ascii <= 'z'-'a'+1) {
-      if ('a'+ascii-1 == 'g')
+    else if (ascii >= 1 && ascii <= 'z' - 'a' + 1) {
+      if ('a' + ascii - 1 == 'g')
         return KBD_CANCEL;
       else
-        return ('a'+ascii-1) | KBD_CTL;
+        return ('a' + ascii - 1) | KBD_CTRL;
     }
     else if (ascii >= ' ') {
       return ascii;
@@ -312,18 +277,14 @@ static int translate_key(int c)
   return KBD_NOKEY;
 }
 
-#define MAX_UNGETKEY_BUF	16
-
-static int ungetkey_buf[MAX_UNGETKEY_BUF];
-static int *ungetkey_p = ungetkey_buf;
-
-static int hooked_readkey(size_t timeout)
+static int hooked_readkey(int mode, size_t timeout)
 {
   size_t beg_time = cur_time;
   term_refresh();
 
   cursor_state = TRUE;
-  while (!keypressed() && (!timeout || cur_time-beg_time < timeout))
+  while (!keypressed() && (!(mode & GETKEY_DELAYED) ||
+                           cur_time - beg_time < timeout))
     draw_cursor(blink_state);
 
   draw_cursor(FALSE);
@@ -332,57 +293,16 @@ static int hooked_readkey(size_t timeout)
   return readkey();
 }
 
-static size_t _getkey(size_t timeout)
-{
-  size_t key;
-
-  if (ungetkey_p > ungetkey_buf)
-    return *--ungetkey_p;
-
-  key = translate_key(hooked_readkey(timeout));
-
-  while (key == KBD_META) {
-    key = translate_key(hooked_readkey(0));
-    key |= KBD_META;
-  }
-
-  return key;
-}
-
-static int _xgetkey(int mode, size_t timeout)
-{
-  int c = 0;
-  switch (mode) {
-  case GETKEY_UNFILTERED:
-    c = hooked_readkey(0) & 0xff;
-    break;
-  case GETKEY_DELAYED:
-    c = _getkey(timeout);
-    break;
-  case GETKEY_UNFILTERED|GETKEY_DELAYED:
-    c = hooked_readkey(timeout) & 0xff;
-    break;
-  default:
-    c = _getkey(0);
-  }
-  return c;
-}
-
 size_t term_xgetkey(int mode, size_t timeout)
 {
-  size_t key;
-
-  if (ungetkey_p > ungetkey_buf)
-    return *--ungetkey_p;
-
-  key = _xgetkey(mode, timeout);
-
-  return key;
-}
-
-void term_ungetkey(size_t key)
-{
-  if (ungetkey_p - ungetkey_buf < MAX_UNGETKEY_BUF &&
-      key != KBD_NOKEY)
-    *ungetkey_p++ = key;
+  if (mode & GETKEY_UNFILTERED)
+    return hooked_readkey(mode, timeout) & 0xff;
+  else {
+    size_t key = translate_key(hooked_readkey(mode, timeout));
+    while (key == KBD_META) {
+      key = translate_key(hooked_readkey(mode, 0));
+      key |= KBD_META;
+    }
+    return key;
+  }
 }
